import pytest

import societeinfo
from societeinfo.exceptions import NoApiKeyProvidedError


def test_societeinfoclient_class_init_ok():
    societeinfo_client = societeinfo.SocieteInfoClient(api_key='some fake api key')

    assert isinstance(societeinfo_client, societeinfo.SocieteInfoClient)
    assert societeinfo_client._api_key == 'some fake api key'


@pytest.mark.parametrize('api_key', [
    None,
    '',
])
def test_societeinfoclient_class_init_no_api_key_provided(api_key):
    with pytest.raises(NoApiKeyProvidedError):
        societeinfo.SocieteInfoClient(api_key=api_key)



import requests_mock

import societeinfo


def test_autocomplete_companies_default_arguments():
    societeinfo_client = societeinfo.SocieteInfoClient(api_key='some fake api key')

    with requests_mock.mock() as m:
        m.get(
            'https://societeinfo.com/app/rest/api/v2/companies.json/autocomplete?'
            'query=Emma%C3%BCs&limit=10&page=1&active=True&withEstablishments=False',
            json={'fake': 'result'},
            status_code=200,
        )

        companies = societeinfo_client.autocomplete_companies('Emmaüs')

    assert companies == {'fake': 'result'}
    assert m.call_count == 1
    assert len(m.request_history) == 1
    assert m.request_history[0].headers['X-API-KEY'] == 'some fake api key'


def test_autocomplete_companies_non_default_arguments():
    societeinfo_client = societeinfo.SocieteInfoClient(api_key='some fake api key')

    with requests_mock.mock() as m:
        m.get(
            'https://societeinfo.com/app/rest/api/v2/companies.json/autocomplete?'
            'query=Emma%C3%BCs&limit=7&page=2&active=False&withEstablishments=True',
            json={'fake': 'result'},
            status_code=200,
        )

        companies = societeinfo_client.autocomplete_companies(
            search='Emmaüs',
            limit=7,
            page=2,
            include_inactive_companies=False,
            include_establishments=True,
        )

    assert companies == {'fake': 'result'}
    assert m.call_count == 1
    assert len(m.request_history) == 1
    assert m.request_history[0].headers['X-API-KEY'] == 'some fake api key'



import requests_mock

import societeinfo


def test_get_credit_details():
    societeinfo_client = societeinfo.SocieteInfoClient(api_key='some fake api key')

    with requests_mock.mock() as m:
        m.get(
            'https://societeinfo.com/app/rest/api/v2/apikeyinfo.json',
            json={'fake': 'result'},
            status_code=200,
        )

        credit_details = societeinfo_client.get_credit_details()

    assert credit_details == {'fake': 'result'}
    assert m.call_count == 1
    assert len(m.request_history) == 1
    assert m.request_history[0].headers['X-API-KEY'] == 'some fake api key'



from setuptools import find_namespace_packages, setup


setup(
    name='societeinfo',
    use_scm_version=True,
    setup_requires=['setuptools_scm'],
    description='Python wrapper to SOCIETE INFO api.',
    long_description='Python wrapper to SOCIETE INFO api. See https://gitlab.com/PierreKephas/societeinfo-python.',
    author='Pierre Kephas',
    url='https://gitlab.com/PierreKephas/societeinfo-python',
    packages=find_namespace_packages(),
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7'
    ],
    keywords=[
    ],
    install_requires=[
        'requests>=2,<3',
    ],
    extras_require={
        'dev': [
            'flake8',
            'flake8-import-order',
            'pytest',
            'pytest-cov',
            'pytest-xdist',
            'requests-mock',
        ],
    },
)



# -*- coding: utf-8 -*-
import requests

from societeinfo.exceptions import NoApiKeyProvidedError


class SocieteInfoClient(object):
    """
    Client object made to process requests to SOCIETE INFO api.
    """
    _SOCIETE_INFO_BASE_URL = 'https://societeinfo.com/app/rest/api/v2'

    def __init__(self, api_key):
        self._api_key = api_key
        if not self._api_key:
            raise NoApiKeyProvidedError('You must provide a valid api key.')

    def _get(self, url_path, query_params=None):
        """
        Generic method to make HTTP calls.

        :param str url_path: URL path concatenated to service "base URL".
        :param dict query_params: Query parameters.
        :rtype: dict
        """
        response = requests.get(
            url=self._SOCIETE_INFO_BASE_URL + url_path,
            params=query_params,
            headers={'X-API-KEY': self._api_key},
        )
        response.raise_for_status()
        return response.json()

    def autocomplete_companies(
            self,
            search,
            limit=10,
            page=1,
            include_inactive_companies=True,
            include_establishments=False,
    ):
        """
        Autocomplete companies from a given search.

        Documentation reference: https://societeinfo.com/api-doc/#autocomplete-company
        Pricing for this call: 0 credits.

        :param str search: Company name or SIREN/SIRET search, two characters minimum.
        :param int limit: Maximum number of results to be retrieved (per page), limited to 25.
        :param int page: Page number of results, starting by default to 1.
        :param bool include_inactive_companies: Whether inactive companies should be included or not.
        :param bool include_establishments: Whether establishments should be included or not.
        :rtype: dict
        """
        return self._get(
            url_path='/companies.json/autocomplete',
            query_params={
                'query': search,
                'limit': limit,
                'page': page,
                'active': include_inactive_companies,
                'withEstablishments': include_establishments,
            },
        )

    def get_company_by_id(self, company_id, include_establishments=False):
        """
        Get a company from its SOCIETE INFO identifier.

        Documentation reference: https://societeinfo.com/api-doc/#get-company
        Pricing for this call: 1 credit / success.

        :param str company_id: SOCIETE INFO identifier.
        :param bool include_establishments: Whether establishments should be included or not.
        :rtype: dict
        """
        return self._get(
            url_path='/company.json/{}'.format(company_id or ''),
            query_params={
                'withEstablishments': include_establishments
            },

        )

    def get_credit_details(self):
        """
        Get credits details.

        See https://societeinfo.com/tarifs/ to learn more about pricing.

        Documentation reference: https://societeinfo.com/api-doc/#credits
        Pricing for this call: 0 credits.

        :rtype: dict
        """
        return self._get(
            url_path='/apikeyinfo.json',
        )



class SocieteInfoError(Exception):
    """
    Base class of all exceptions of this library.
    """


class NoApiKeyProvidedError(SocieteInfoError):
    """
    Error raised when no api key is provided.
    """
